@@ -43,6 +43,7 @@ def plot_4D(
     font_size_title=12,
     font_size_label=10,
     font_size_legend=8,
+    is_grid=False,
 ):
     """Plots a 4D graph
 
@@ -146,7 +147,7 @@ def plot_4D(
 
     if is_same_size:
         Sdata = zeros_like(Zdata)
-        Sdata[Zdata > z_max / 1e4] = 20
+        Sdata[Zdata > z_max / 1e4] = 40
     elif Sdata is None:
         Sdata = 500 * Zdata / z_max
 
@@ -177,6 +178,8 @@ def plot_4D(
             cmap=colormap,
             vmin=z_min,
             vmax=z_max,
+            picker=True,
+            pickradius=5,
         )
         clb = fig.colorbar(c, ax=ax, format=clb_format)
         clb.ax.set_title(zlabel, fontsize=font_size_legend, fontname=font_name)
@@ -234,6 +237,9 @@ def plot_4D(
     ax.title.set_fontsize(font_size_title)
     ax.title.set_fontname(font_name)
 
+    if is_grid:
+        ax.grid()
+
     if save_path is not None:
         save_path = save_path.replace("\\", "/")
         fig.savefig(save_path)
@@ -241,6 +247,8 @@ def plot_4D(
 
     if is_show_fig:
         fig.show()
-    
+
     if win_title:
-        fig.canvas.set_window_title(win_title)
+        manager = plt.get_current_fig_manager()
+        if manager is not None:
+            manager.set_window_title(win_title)
