@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from numpy import pi, sqrt, inf  # for eval
 from SciDataTool.Functions import AxisError
 from SciDataTool.Classes.RequestedAxis import RequestedAxis
@@ -67,6 +66,11 @@ def read_input_strings(args, axis_data):
             elems = axis_str.split("=integrate")
             name = elems[0]
             extension = "integrate"
+        # Detect antiderivate
+        elif "antiderivate" in axis_str:
+            elems = axis_str.split("=antiderivate")
+            name = elems[0]
+            extension = "antiderivate"
         # Detect derivate
         elif "derivate" in axis_str:
             elems = axis_str.split("=derivate")
@@ -97,7 +101,7 @@ def read_input_strings(args, axis_data):
             extension = "axis_data"
             try:
                 input_data = axis_data[name]
-            except:
+            except Exception:
                 raise AxisError("ERROR: No axis_data provided")
         # Detect above
         elif ">" in axis_str:
