@@ -17,6 +17,8 @@ def freq_to_time(self):
     # Dynamic import to avoid loop
     module = __import__("SciDataTool.Classes.DataTime", fromlist=["DataTime"])
     DataTime = getattr(module, "DataTime")
+    module = __import__("SciDataTool.Classes.DataPattern", fromlist=["DataPattern"])
+    DataPattern = getattr(module, "DataPattern")
 
     axes_str = []
     for i, axis in enumerate(self.axes):
@@ -26,8 +28,10 @@ def freq_to_time(self):
             axis_str = "time[smallestperiod]"
         elif axis.name == "wavenumber":
             axis_str = "angle[smallestperiod]"
+        elif isinstance(axis, DataPattern):
+            axis_str = axis.name + "[pattern]"
         else:
-            axis_str = axis.name
+            axis_str = axis.name + "[smallestperiod]"
         axes_str.append(axis_str)
     if axes_str == [axis.name for axis in self.axes]:
         raise AxisError(
@@ -38,36 +42,28 @@ def freq_to_time(self):
         values = results.pop(self.symbol)
         Axes = []
         for axis in self.axes:
-            if axis.is_components:  # components axis
-                name = axis.name
-                is_components = True
-                axis_values = axis.values
-                unit = "SI"
-            elif axis.name == "freqs":
-                name = "time"
-                is_components = False
-                axis_values = results["time"]
-                unit = "s"
-            elif axis.name == "wavenumber":
-                name = "angle"
-                is_components = False
-                axis_values = results["angle"]
-                unit = "rad"
-            else:
-                name = axis.name
-                is_components = False
-                axis_values = results[axis.name]
-                unit = axis.unit
-            Axes.append(
-                Data1D(
-                    name=name,
-                    unit=unit,
-                    values=axis_values,
-                    is_components=is_components,
+            if axis.name == "freqs":
+                axis_new = Data1D(
+                    name="time",
+                    is_components=False,
+                    values=results["time"],
+                    unit="s",
                     symmetries=axis.symmetries.copy(),
                     normalizations=axis.normalizations.copy(),
                 )
-            )
+            elif axis.name == "wavenumber":
+                axis_new = Data1D(
+                    name="angle",
+                    is_components=False,
+                    values=results["angle"],
+                    unit="rad",
+                    symmetries=axis.symmetries.copy(),
+                    normalizations=axis.normalizations.copy(),
+                )
+            else:
+                axis_new = axis.copy()
+            Axes.append(axis_new)
+
         return DataTime(
             name=self.name,
             unit=self.unit,
@@ -75,4 +71,5 @@ def freq_to_time(self):
             axes=Axes,
             values=values,
             is_real=self.is_real,
+            normalizations=self.normalizations.copy(),
         )
