@@ -40,6 +40,7 @@ def get_axis(self, axis, is_real):
             "mean",
             "rms",
             "integrate",
+            "antiderivate",
             "derivate",
             "list",
         ]:
@@ -87,7 +88,10 @@ def get_axis(self, axis, is_real):
                 is_oneperiod = True
                 is_antiperiod = False
         elif self.extension in ["sum", "rss", "mean", "rms", "integrate", "derivate"]:
-            is_smallestperiod = False
+            if self.is_pattern:
+                is_smallestperiod = False
+            else:
+                is_smallestperiod = True
             is_oneperiod = False
             is_antiperiod = False
         # Ignore symmetries if fft axis
