@@ -1,6 +1,6 @@
-from numpy import column_stack, array, max as np_max
+from numpy import column_stack, array, exp, real, squeeze
 from SciDataTool.Functions.Plot.plot_2D import plot_2D
-from SciDataTool.Functions.conversions import rphiz_to_xyz
+from SciDataTool.Functions.conversions import rphiz_to_xyz, xyz_to_rphiz, rphiz_to_xyz_field
 
 
 def plot_2D_Data(
@@ -44,6 +44,7 @@ def plot_2D_Data(
     scale_units="x",
     scale=None,
     width=0.005,
+    phase=0,
 ):
     """Plots a field as a function of time
 
@@ -115,18 +116,54 @@ def plot_2D_Data(
 
     # Special case of quiver plot
     if type_plot == "quiver":
-        result = self.get_xyz_along(
-            arg_list, axis_data=axis_data, unit=unit, is_norm=is_norm
-        )
-        if "x" in result and "y" in result:
-            Xdatas = column_stack((result["x"], result["y"]))
+        
+        if component_list is None:
+            result = self.get_xyz_along(
+                arg_list, axis_data=axis_data, unit=unit, is_norm=is_norm,
+            )
+
+            if "x" in result and "y" in result:
+                Xdatas = column_stack((result["x"], result["y"]))
+            else:
+                if radius is None:
+                    radius = 1
+                phi = result["angle"]
+                rphi = column_stack((array([radius] * len(phi)), phi))
+                Xdatas = rphiz_to_xyz(rphi)
+
+            Ydatas = column_stack((squeeze(result["comp_x"]), squeeze(result["comp_y"])))
         else:
-            if radius is None:
-                radius = 1
-            phi = result["angle"]
-            rphi = column_stack((array([radius] * len(phi)), phi))
-            Xdatas = rphiz_to_xyz(rphi)
-        Ydatas = column_stack((result["comp_x"], result["comp_y"]))
+            result = self.components[component_list[0]].get_along(
+                arg_list, axis_data=axis_data, unit=unit, is_norm=is_norm,
+            )
+            Y_comp = result[self.components[component_list[0]].symbol]
+
+            if "x" in result and "y" in result:
+                Xdatas = column_stack((result["x"], result["y"]))
+                rphiz = xyz_to_rphiz(Xdatas)
+
+                if component_list[0] == "radial":
+                    Y_3d = column_stack((Y_comp, 0*Y_comp, 0*Y_comp))
+                else:
+                    Y_3d = column_stack((0*Y_comp, Y_comp, 0*Y_comp))
+
+                Ydatas = rphiz_to_xyz_field(Y_3d, rphiz[:,1])
+
+            else:
+                if radius is None:
+                    radius = 1
+                phi = result["angle"]
+                rphi = column_stack((array([radius] * len(phi)), phi))
+                Xdatas = rphiz_to_xyz(rphi)
+                if component_list[0] == "radial":
+                    Y_3d = column_stack((Y_comp, 0*Y_comp, 0*Y_comp))
+                else:
+                    Y_3d = column_stack((0*Y_comp, Y_comp, 0*Y_comp))
+
+                Ydatas = rphiz_to_xyz_field(Y_3d, phi)
+
+        Ydatas = real(Ydatas*exp(1j*phase))
+
         # Normalize Ydatas
         # Ydatas = Ydatas / (np_max(Ydatas) * 0.001 * radius)
         plot_2D(
